# coding: utf-8

"""
    SparkWorks Core API

    Management Service for the SparkWorks Processing Engine  # noqa: E501

    OpenAPI spec version: v2.0
    Contact: info@sparkworks.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class ParticipatorySensingDataAPIModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'resource_uuid': 'str',
        'time': 'int',
        'value': 'float'
    }

    attribute_map = {
        'resource_uuid': 'resourceUuid',
        'time': 'time',
        'value': 'value'
    }

    def __init__(self, resource_uuid=None, time=None, value=None):  # noqa: E501
        """ParticipatorySensingDataAPIModel - a model defined in Swagger"""  # noqa: E501

        self._resource_uuid = None
        self._time = None
        self._value = None
        self.discriminator = None

        self.resource_uuid = resource_uuid
        self.time = time
        self.value = value

    @property
    def resource_uuid(self):
        """Gets the resource_uuid of this ParticipatorySensingDataAPIModel.  # noqa: E501

        The resource unique identifier  # noqa: E501

        :return: The resource_uuid of this ParticipatorySensingDataAPIModel.  # noqa: E501
        :rtype: str
        """
        return self._resource_uuid

    @resource_uuid.setter
    def resource_uuid(self, resource_uuid):
        """Sets the resource_uuid of this ParticipatorySensingDataAPIModel.

        The resource unique identifier  # noqa: E501

        :param resource_uuid: The resource_uuid of this ParticipatorySensingDataAPIModel.  # noqa: E501
        :type: str
        """
        if resource_uuid is None:
            raise ValueError("Invalid value for `resource_uuid`, must not be `None`")  # noqa: E501

        self._resource_uuid = resource_uuid

    @property
    def time(self):
        """Gets the time of this ParticipatorySensingDataAPIModel.  # noqa: E501

        The UNIX timestamp of the measurement  # noqa: E501

        :return: The time of this ParticipatorySensingDataAPIModel.  # noqa: E501
        :rtype: int
        """
        return self._time

    @time.setter
    def time(self, time):
        """Sets the time of this ParticipatorySensingDataAPIModel.

        The UNIX timestamp of the measurement  # noqa: E501

        :param time: The time of this ParticipatorySensingDataAPIModel.  # noqa: E501
        :type: int
        """
        if time is None:
            raise ValueError("Invalid value for `time`, must not be `None`")  # noqa: E501

        self._time = time

    @property
    def value(self):
        """Gets the value of this ParticipatorySensingDataAPIModel.  # noqa: E501

        The actual value of the measurement  # noqa: E501

        :return: The value of this ParticipatorySensingDataAPIModel.  # noqa: E501
        :rtype: float
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this ParticipatorySensingDataAPIModel.

        The actual value of the measurement  # noqa: E501

        :param value: The value of this ParticipatorySensingDataAPIModel.  # noqa: E501
        :type: float
        """
        if value is None:
            raise ValueError("Invalid value for `value`, must not be `None`")  # noqa: E501

        self._value = value

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ParticipatorySensingDataAPIModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ParticipatorySensingDataAPIModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
